# EmbryoSeg
Segmentation tool for multiple touching animal embryo cells using SmartSeeds



[![Build Status](https://travis-ci.com/kapoorlab/napatrackmater.svg?branch=master)](https://travis-ci.com/github/kapoorlab/embryoseg)
[![PyPI version](https://img.shields.io/pypi/v/napatrackmater.svg?maxAge=2591000)](https://pypi.org/project/embryoseg/)


## Usage
Check the [Training notebook](https://github.com/kapoorlab/EmbryoSeg/blob/main/notebooks/ColabTrainModel.ipynb).

Check the [Prediction notebook](https://github.com/kapoorlab/EmbryoSeg/blob/main/notebooks/ColabEmbryoSeg.ipynb).

## Requirements

- Python 3.9 and above.

## Install

`pip install embryoseg`



## License

Under MIT license. See [LICENSE](LICENSE).

## Authors

- Varun Kapoor <randomaccessiblekapoor@gmail.com>
